@@ -22,7 +22,7 @@ import sys
 from avocado.core.loader import loader
 from avocado.core.plugin_interfaces import CLI
 
-from virttest.compat import get_settings_value
+from virttest.compat import get_settings_value, add_option
 from .vt import add_basic_vt_options, add_qemu_bin_vt_option
 from ..loader import VirtTestLoader
 
@@ -96,20 +96,27 @@ class VTLister(CLI):
 
         vt_compat_group_lister = list_subcommand_parser.add_argument_group(
             'Virt-Test compat layer - Lister options')
-        vt_compat_group_lister.add_argument("--vt-list-guests",
-                                            action="store_true",
-                                            default=False,
-                                            help="Also list the available "
-                                            "guests (this option ignores the "
-                                            "--vt-config and --vt-guest-os)")
-        vt_compat_group_lister.add_argument("--vt-list-archs", default=False,
-                                            action="store_true",
-                                            help="Also list the available "
-                                            "arch/machines for the given "
-                                            "guest OS. (Use \"--vt-guest-os "
-                                            "''\" to see all combinations; "
-                                            "--vt-config --vt-machine-type "
-                                            "and --vt-arch args are ignored)")
+
+        help_msg = ("Also list the available guests (this option ignores the "
+                    "--vt-config and --vt-guest-os)")
+        add_option(parser=vt_compat_group_lister,
+                   dest='vt.list_guests',
+                   arg='--vt-list-guests',
+                   action='store_true',
+                   default=False,
+                   help=help_msg)
+
+        help_msg = ("Also list the available arch/machines for the given guest"
+                    " OS. (Use \"--vt-guest-os ''\" to see all combinations; "
+                    "--vt-config --vt-machine-type and --vt-arch args are "
+                    "ignored)")
+        add_option(parser=vt_compat_group_lister,
+                   dest='vt.list_archs',
+                   arg='--vt-list-archs',
+                   action='store_true',
+                   default=False,
+                   help=help_msg)
+
         add_basic_vt_options(vt_compat_group_lister)
         add_qemu_bin_vt_option(vt_compat_group_lister)
 
