@@ -86,8 +86,8 @@ else:
 
 def get_kvm_module_list():
     if ARCH == 'x86_64':
-        host_cpu_type = cpu.get_cpu_vendor_name()
-        return ["kvm", "kvm-%s" % host_cpu_type]
+        vendor = cpu.get_vendor() if hasattr(cpu, 'get_vendor') else cpu.get_cpu_vendor_name()
+        return ["kvm", "kvm-%s" % vendor]
     elif ARCH in ('ppc64', 'ppc64le'):
         # FIXME: Please correct it if anyone still want to use KVM-PR mode
         return ["kvm", "kvm-hv"]
