@@ -52,6 +52,7 @@ from virttest import utils_qemu
 from virttest import migration
 from virttest import utils_kernel_module
 from virttest import arch
+from virttest.utils_conn import SSHConnection
 from virttest.utils_version import VersionInterval
 from virttest.staging import service
 
@@ -160,24 +161,26 @@ def preprocess_fs_source(test, params, fs_name, vm_process_status=None):
                               process_fs_sources()
     """
     fs_type = params.get('fs_source_type', 'mount')
+    fs_source_user_config = params.get('fs_source_user_config', 'no')
     # mount: A host directory to mount in the vm.
     if fs_type == 'mount':
-        fs_source = params.get('fs_source_dir')
-        base_dir = params.get("fs_source_base_dir", data_dir.get_data_dir())
-        if not os.path.isabs(fs_source):
-            fs_source = os.path.join(base_dir, fs_source)
+        if fs_source_user_config == "no":
+            fs_source = params.get('fs_source_dir')
+            base_dir = params.get("fs_source_base_dir", data_dir.get_data_dir())
+            if not os.path.isabs(fs_source):
+                fs_source = os.path.join(base_dir, fs_source)
 
-        create_fs_source = False
-        if params.get("force_create_fs_source") == "yes":
-            create_fs_source = True
-        elif params.get("create_fs_source") == "yes" and not os.path.exists(fs_source):
-            create_fs_source = True
+            create_fs_source = False
+            if params.get("force_create_fs_source") == "yes":
+                create_fs_source = True
+            elif params.get("create_fs_source") == "yes" and not os.path.exists(fs_source):
+                create_fs_source = True
 
-        if create_fs_source:
-            if os.path.exists(fs_source):
-                shutil.rmtree(fs_source, ignore_errors=True)
-            logging.info("Create filesystem source %s." % fs_source)
-            os.makedirs(fs_source)
+            if create_fs_source:
+                if os.path.exists(fs_source):
+                    shutil.rmtree(fs_source, ignore_errors=True)
+                logging.info("Create filesystem source %s." % fs_source)
+                os.makedirs(fs_source)
     else:
         test.cancel('Unsupport the type of filesystem "%s"' % fs_type)
 
@@ -1145,6 +1148,11 @@ def preprocess(test, params, env):
             session.close()
             test.cancel("Failed to map hostname and ipaddress of target host")
         session.close()
+        if params.get("setup_ssh") == "yes":
+            ssh_conn_obj = SSHConnection(params)
+            ssh_conn_obj.conn_setup()
+            ssh_conn_obj.auto_recover = True
+            params.update({"ssh_conn_obj": ssh_conn_obj})
 
     # Destroy and remove VMs that are no longer needed in the environment or
     # leave them untouched if they have to be disregarded only for this test
@@ -1831,6 +1839,8 @@ def postprocess(test, params, env):
                                                       params.get("remote_ip")))
         migrate_setup = migration.MigrationTest()
         migrate_setup.migrate_pre_setup(dest_uri, params, cleanup=True)
+        if params.get("setup_ssh") == "yes" and params.get("ssh_conn_obj"):
+            del params["ssh_conn_obj"]
 
     setup_pb = False
     ovs_pb = False
