@@ -174,7 +174,14 @@ class CgroupTest(object):
                             dev_list.append(dev_num)
         elif virsh_cmd == "memtune":
             cgroup_path = self.get_cgroup_path("memory")
-            max_mem_value = "9223372036854771712"
+            cmd = "getconf PAGE_SIZE"
+            page_size = process.run(cmd, ignore_status=True, shell=True).stdout_text.strip()
+            logging.debug("page_size is %d" % int(page_size))
+            if int(page_size) == 65536:
+                max_mem_value = "9223372036854710272"
+            else:
+                max_mem_value = "9223372036854771712"
+            logging.debug("max_mem_value is %s" % max_mem_value)
             for cg_key, cg_file_name in list(CGROUP_V1_MEM_FILE_MAPPING.items()):
                 with open(os.path.join(cgroup_path, cg_file_name), 'r') as cg_file:
                     cg_file_value = cg_file.read().strip()
@@ -224,7 +231,8 @@ class CgroupTest(object):
         if virsh_cmd == "blkiotune":
             weight_file_name = CGROUP_V2_BLKIO_FILE_MAPPING["weight"]
             iomax_file_name = CGROUP_V2_BLKIO_FILE_MAPPING["wiops"]
-            path_to_weight = os.path.join(cgroup_path, weight_file_name)
+            path_to_weight = os.path.join(cgroup_path.split("libvirt")[0],
+                                          weight_file_name)
             with open(path_to_weight, 'r') as weight_file:
                 weight_value = re.search(r'\d+', weight_file.read())
                 if weight_value:
@@ -257,7 +265,10 @@ class CgroupTest(object):
                         cg_file_name = cg_file_name.replace("<iothreadX>", iothread_dirs[0])
                     else:
                         continue
-                with open(os.path.join(cgroup_path, cg_file_name), 'r') as cg_file:
+                cg_dir = cgroup_path
+                if cg_key == "cpu_shares":
+                    cg_dir = cgroup_path.split("libvirt")[0]
+                with open(os.path.join(cg_dir, cg_file_name), 'r') as cg_file:
                     list_index = 0
                     cg_file_values = cg_file.read().strip().split()
                     if "period" in cg_key:
