@@ -120,6 +120,10 @@ class IPXML(base.LibvirtXMLBase):
         """
         if isinstance(item, DhcpHostXML):
             return 'host', item
+        elif isinstance(item, dict):
+            host = DhcpHostXML()
+            host.setup_attrs(**item)
+            return 'host', host
         else:
             raise xcepts.LibvirtXMLError("Expected a list of ip dhcp host "
                                          "instances, not a %s" % str(item))
@@ -159,27 +163,34 @@ class DhcpHostXML(base.LibvirtXMLBase):
 class DNSXML(base.LibvirtXMLBase):
 
     """
-    IP address block, optionally containing DHCP range information
+    DNS block, contains configuration information for the network's DNS server
 
     Properties:
+        enable:
+            String, 'yes' or 'no'. Set to "no", then no DNS server
+            will be set by libvirt for this network
         txt:
             Dict. keys: name, value
-        forwarder:
+        forwarders:
             List
+        dns_forward:
+            String, 'yes' or 'no'
         srv:
             Dict. keys: service, protocol, domain,
-            tartget, port, priority, weight
-        hosts:
+            target, port, priority, weight
+        host:
             List of host name
     """
 
-    __slots__ = ('dns_forward', 'txt', 'forwarders', 'srv',
+    __slots__ = ('enable', 'dns_forward', 'txt', 'forwarders', 'srv',
                  'host')
 
     def __init__(self, virsh_instance=base.virsh):
         """
         Create new IPXML instance based on address/mask
         """
+        accessors.XMLAttribute('enable', self, parent_xpath='/',
+                               tag_name='dns', attribute='enable')
         accessors.XMLElementDict('txt', self,
                                  parent_xpath='/',
                                  tag_name='txt')
