@@ -153,7 +153,7 @@ class Nfs(object):
 
     """
     Nfs class for handle nfs mount and umount. If a local nfs service is
-    required, it will configure a local nfs server accroding the params.
+    required, it will configure a local nfs server according the params.
     """
 
     def __init__(self, params):
@@ -234,9 +234,10 @@ class Nfs(object):
         service and exportfs too.
         """
         if self.nfs_setup:
-            logging.debug("Restart NFS service.")
-            self.rpcbind_service.restart()
-            self.nfs_service.restart()
+            if not self.nfs_service.status():
+                logging.debug("Restart NFS service.")
+                self.rpcbind_service.restart()
+                self.nfs_service.restart()
 
             if not utils_misc.check_isdir(self.export_dir, session=self.session):
                 utils_misc.make_dirs(self.export_dir, session=self.session)
