@@ -293,7 +293,7 @@ class UnattendedInstallConfig(object):
         """
         Get windows driver's hardware id from inf files.
 
-        :param dirver: Configurable driver name.
+        :param driver: Configurable driver name.
         :param run_cmd:  Use hardware id in windows cmd command or not.
         :return: Windows driver's hardware id
         """
@@ -409,6 +409,17 @@ class UnattendedInstallConfig(object):
             rh_system_stream_id = self.params.get("rh_system_stream_id", "")
             contents = re.sub(dummy_rh_system_stream_id_re, rh_system_stream_id, contents)
 
+        dummy_rh_guest_compose_meta_re = r'\bRH_GUEST_COMPOSE_META\b'
+        if re.search(dummy_rh_guest_compose_meta_re, contents):
+            rh_guest_compose_meta = ""
+            cdrom_meta_cd1 = self.params.get("cdrom_meta_cd1", "")
+            if cdrom_meta_cd1:
+                cdrom_meta_cd1 = os.path.join(data_dir.get_data_dir(),
+                                              cdrom_meta_cd1)
+                with open(cdrom_meta_cd1, 'r') as f:
+                    rh_guest_compose_meta = f.read()
+            contents = re.sub(dummy_rh_guest_compose_meta_re, rh_guest_compose_meta, contents)
+
         dummy_repos_re = r'\bKVM_TEST_REPOS\b'
         if re.search(dummy_repos_re, contents):
             repo_list = self.params.get("kickstart_extra_repos", "").split()
@@ -781,7 +792,7 @@ class UnattendedInstallConfig(object):
                 if '%s=' % self.unattended_file_kernel_param_name in kernel_params:
                     # Reading ks from floppy directly doesn't work in some OS,
                     # options 'ks=hd:/dev/fd0' can reading ks from mounted
-                    # floppy, so skip repace it;
+                    # floppy, so skip replace it;
                     if not re.search("fd\d+", kernel_params):
                         kernel_params = re.sub('%s=[\w\d\-:\./]+' %
                                                (self.unattended_file_kernel_param_name),
