@@ -521,7 +521,7 @@ def session_handler(func):
                 vm.connect_uri = uri
                 vm.session = vm.wait_for_serial_login()
             else:
-                vm.session = vm.wait_for_login()
+                vm.session = vm.wait_for_login(serial=True)
             return func(vm, *args, **kwargs)
         finally:
             if vm.session:
@@ -942,7 +942,7 @@ class BaseVM(object):
         if 'mac' not in nic:  # generate random mac
             logging.debug("Generating random mac address for nic")
             self.virtnet.generate_mac_address(nic_name)
-        # mac of '' or invaid format results in not setting a mac
+        # mac of '' or invalid format results in not setting a mac
         if 'ip' in nic and 'mac' in nic:
             self.address_cache[nic.mac] = nic.ip
         return nic
@@ -1099,10 +1099,12 @@ class BaseVM(object):
         log_filename = ("session-%s-%s-%s.log" %
                         (self.name, time.strftime("%m-%d-%H-%M-%S"),
                          utils_misc.generate_random_string(4)))
+        log_filename = utils_misc.get_log_filename(log_filename)
+        log_function = utils_misc.log_line
         session = remote.remote_login(client, address, port, username,
                                       password, prompt, linesep,
-                                      log_filename, timeout,
-                                      interface=neigh_attach_if)
+                                      log_filename, log_function,
+                                      timeout, interface=neigh_attach_if)
         session.set_status_test_command(self.params.get("status_test_command",
                                                         ""))
         self.remote_sessions.append(session)
